@@ -2,7 +2,10 @@ from __future__ import absolute_import
 import sys
 import itertools
 import platform
-import unittest
+if sys.version_info < (2, 7):
+    import unittest2 as unittest
+else:
+    import unittest
 from .call import EMPTY_CALL
 from .parameters import get_parameter_spec
 from .parameters import NO_SPEC_ID
